@@ -7,7 +7,7 @@ Attean::API::Model - RDF Model
 
 =head1 VERSION
 
-This document describes Attean::API::Model version 0.033
+This document describes Attean::API::Model version 0.034
 
 =head1 DESCRIPTION
 
@@ -166,12 +166,12 @@ in the model.
 
 use Attean::API::Binding;
 
-package Attean::API::Model 0.033 {
+package Attean::API::Model 0.034 {
 	use Sub::Install;
 	use Sub::Util qw(set_subname);
 	use URI::Namespace;
 	use Scalar::Util qw(blessed);
-	use List::MoreUtils qw(uniq);
+	use List::Util qw(uniq);
 	use Math::Cartesian::Product;
 	use Data::Dumper;
 
@@ -379,7 +379,7 @@ package Attean::API::Model 0.033 {
 }
 
 
-package Attean::API::MutableModel 0.033 {
+package Attean::API::MutableModel 0.034 {
 	use Attean::RDF;
 	use LWP::UserAgent;
 	use Encode qw(encode);
@@ -488,21 +488,21 @@ package Attean::API::MutableModel 0.033 {
 }
 
 
-package Attean::API::ETagCacheableModel 0.033 {
+package Attean::API::ETagCacheableModel 0.034 {
 	use Moo::Role;
 	
 	requires 'etag_value_for_quads';
 }
 
 
-package Attean::API::TimeCacheableModel 0.033 {
+package Attean::API::TimeCacheableModel 0.034 {
 	use Moo::Role;
 	
 	requires 'mtime_for_quads';
 }
 
 
-package Attean::API::BulkUpdatableModel 0.033 {
+package Attean::API::BulkUpdatableModel 0.034 {
 	use Moo::Role;
 	
 	with 'Attean::API::MutableModel';
@@ -525,7 +525,7 @@ package Attean::API::BulkUpdatableModel 0.033 {
 	};
 }
 
-package Attean::API::RDFStarModel 0.033 {
+package Attean::API::RDFStarModel 0.034 {
 	use Moo::Role;
 
 	with 'Attean::API::Model';
