@@ -7,7 +7,7 @@ Attean::Expression - SPARQL Expressions
 
 =head1 VERSION
 
-This document describes Attean::Expression version 0.033
+This document describes Attean::Expression version 0.034
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,7 @@ use Attean::API::Expression;
 
 =cut
 
-package Attean::ValueExpression 0.033 {
+package Attean::ValueExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use AtteanX::SPARQL::Constants;
@@ -101,7 +101,7 @@ package Attean::ValueExpression 0.033 {
 
 =cut
 
-package Attean::UnaryExpression 0.033 {
+package Attean::UnaryExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(Enum);
 	use namespace::clean;
@@ -138,7 +138,7 @@ package Attean::UnaryExpression 0.033 {
 
 =cut
 
-package Attean::BinaryExpression 0.033 {
+package Attean::BinaryExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(Enum);
 	use namespace::clean;
@@ -166,7 +166,7 @@ package Attean::BinaryExpression 0.033 {
 
 =cut
 
-package Attean::FunctionExpression 0.033 {
+package Attean::FunctionExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(Enum ConsumerOf HashRef);
 	use Types::Common::String qw(UpperCaseStr);
@@ -217,8 +217,16 @@ package Attean::FunctionExpression 0.033 {
 		my $comma	= AtteanX::SPARQL::Token->comma;
 
 		my @tokens;
-		push(@tokens, $func, $lparen);
-		foreach my $t (@{ $self->children }) {
+		my @children	= @{ $self->children };
+		if ($self->operator eq 'INVOKE') {
+			my $iri	= shift(@children);
+			push(@tokens, $iri->sparql_tokens->elements);
+			push(@tokens, $lparen);
+		} else {
+			push(@tokens, $func, $lparen);
+		}
+		
+		foreach my $t (@children) {
 			push(@tokens, $t->sparql_tokens->elements);
 			push(@tokens, $comma);
 		}
@@ -230,7 +238,7 @@ package Attean::FunctionExpression 0.033 {
 	}
 }
 
-package Attean::AggregateExpression 0.033 {
+package Attean::AggregateExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(Bool Enum Str HashRef ConsumerOf Maybe ArrayRef);
 	use Types::Common::String qw(UpperCaseStr);
@@ -303,7 +311,7 @@ package Attean::AggregateExpression 0.033 {
 	}
 }
 
-package Attean::CastExpression 0.033 {
+package Attean::CastExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(Enum ConsumerOf);
 	use AtteanX::SPARQL::Constants;
@@ -355,7 +363,7 @@ package Attean::CastExpression 0.033 {
 	}
 }
 
-package Attean::ExistsExpression 0.033 {
+package Attean::ExistsExpression 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -407,7 +415,7 @@ package Attean::ExistsExpression 0.033 {
 	}
 }
 
-package Attean::ExistsPlanExpression 0.033 {
+package Attean::ExistsPlanExpression 0.034 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
