@@ -4,7 +4,7 @@ AtteanX::Serializer::TextTable - SPARQL Results TSV Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::TextTable version 0.028
+This document describes AtteanX::Serializer::TextTable version 0.034
 
 =head1 SYNOPSIS
 
@@ -35,13 +35,13 @@ This document describes AtteanX::Serializer::TextTable version 0.028
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::TextTable 0.028 {
+package AtteanX::Serializer::TextTable 0.034 {
 	use Moo;
 	use Types::Standard qw(Str Bool ArrayRef);
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
 	use Attean::ListIterator;
-	use List::MoreUtils qw(any);
+	use List::Util qw(any);
 	use Text::Table;
 	use namespace::clean;
 
@@ -65,7 +65,7 @@ Returns a list of file extensions associated with the serialized format.
 
 =cut
 
-	sub file_extensions { return [qw(txt)] };
+	sub file_extensions { return [qw(txt text)] };
 	
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
 
@@ -187,7 +187,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
