@@ -4,7 +4,7 @@ AtteanX::Serializer::Turtle - Turtle Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::Turtle version 0.028
+This document describes AtteanX::Serializer::Turtle version 0.034
 
 =head1 SYNOPSIS
 
@@ -39,12 +39,12 @@ This document describes AtteanX::Serializer::Turtle version 0.028
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::Turtle 0.028 {
+package AtteanX::Serializer::Turtle 0.034 {
 	use Moo;
 	use Data::Dumper;
 	use Encode qw(encode);
 	use Attean::ListIterator;
-	use List::MoreUtils qw(any);
+	use List::Util qw(any);
 	use AtteanX::Parser::Turtle::Constants;
 	use AtteanX::Parser::Turtle::Token;
 	use AtteanX::Serializer::TurtleTokens;
@@ -200,7 +200,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
